@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008-2010 Wind River Systems; see
+ * Copyright (c) 2008-2010, 2012 Wind River Systems; see
  * guts/COPYRIGHT for information.
  *
  * static int
@@ -7,15 +7,15 @@
  *	int rc = -1;
  */
  	pseudo_msg_t *msg;
-	struct stat buf;
+	PSEUDO_STATBUF buf;
 	int save_errno = errno;
 
-	if (real_fstat(fd, &buf) == -1) {
+	if (base_fstat(fd, &buf) == -1) {
 		/* can't stat it, can't chmod it */
 		return -1;
 	}
 	buf.st_mode = (buf.st_mode & ~07777) | (mode & 07777);
-	msg = pseudo_client_op_plain(OP_FCHMOD, 0, fd, -1, 0, &buf);
+	msg = pseudo_client_op(OP_FCHMOD, 0, fd, -1, 0, &buf);
 	real_fchmod(fd, PSEUDO_FS_MODE(mode, S_ISDIR(buf.st_mode)));
 	if (msg && msg->result != RESULT_SUCCEED) {
 		errno = EPERM;
