@@ -1,12 +1,12 @@
 /* 
- * Copyright (c) 2010 Wind River Systems; see
+ * Copyright (c) 2010, 2012 Wind River Systems; see
  * guts/COPYRIGHT for information.
  *
  * static DIR *
  * wrap_opendir(const char *path) {
  *	DIR * rc = NULL;
  */
- 	struct stat buf;
+ 	PSEUDO_STATBUF buf;
 	int save_errno;
 
 	rc = real_opendir(path);
@@ -14,12 +14,12 @@
 		int fd;
 		save_errno = errno;
 		fd = dirfd(rc);
-		if (real_fstat(fd, &buf) == -1) {
+		if (base_fstat(fd, &buf) == -1) {
 			pseudo_debug(1, "diropen (fd %d) succeeded, but fstat failed (%s).\n",
 				fd, strerror(errno));
-			pseudo_client_op_plain(OP_OPEN, PSA_READ, fd, -1, path, 0);
+			pseudo_client_op(OP_OPEN, PSA_READ, fd, -1, path, 0);
 		} else {
-			pseudo_client_op_plain(OP_OPEN, PSA_READ, fd, -1, path, &buf);
+			pseudo_client_op(OP_OPEN, PSA_READ, fd, -1, path, &buf);
 		}
 
 
